<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});

Route::post('/store-image-url', function (Request $request) {
    // Validasi input
    $request->validate([
        'image_url' => 'required|url',
    ]);

    $imageUrl = $request->input('image_url');
    try {
        // Mengambil konten gambar dari URL
        $imageContent = file_get_contents($imageUrl);
        if ($imageContent === false) {
            return response()->json(['status' => 'error', 'message' => 'Gagal mengambil gambar dari URL'], 500);
        }

        // Menentukan nama file dan menyimpan gambar
        $timestamp = now()->format('Ymd_His');
        $filename = "hikvision_snapshot_{$timestamp}.jpg";
        Storage::disk('public')->put("hikvision/{$filename}", $imageContent);

        return response()->json(['status' => 'success', 'image_path' => "hikvision/{$filename}"]);
    } catch (\Exception $e) {
        return response()->json(['status' => 'error', 'message' => $e->getMessage()], 500);
    }
});
